==> image-data-domain-0.0.96-sources.jar: com/xforceplus/elephant/entity/BankBill.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-01
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class BankBill implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String batchNo;

  private String billTypeCode;

  private String billCode;

  private BigDecimal billAmountWithTax;

  private BigDecimal billTaxAmount;

  private BigDecimal billAmountWithoutTax;

  private String billCreateUser;

  private LocalDateTime billCreateTime;

  private Long scanUserId;

  private String scanUserName;

  private LocalDateTime scanCreateTime;

  private String packageCode;

  private String logisticsStatus;

  private LocalDateTime logisticsTime;

  private String signStatus;

  private LocalDateTime signTime;

  private String isPublic;

  private String logisticRemark;

  private String hangType;

  private String hangReason;

  private String backType;

  private String backReason;

  private String billDataStatus;

  private LocalDateTime billDataTime;

  private String verifyStatus;

  private LocalDateTime verifyTime;

  private Long ticketCount;

  private Long imageCount;

  private Long exceptionCount;

  private Long warningCount;

  private String isException;

  private String exceptionInfo;

  private String systemOrig;

  private String isSecret;

  private String backRemark;

  private String unqualityType;

  private String unqualityReason;

  private String verifyHangType;

  private String verifyHangReason;

  private String isPrepayment;

  private String extFields;

  private String extStatus;

  private String prepaymentStatus;

  private LocalDateTime prepaymentTime;

  private String createUserCode;

  private String sellerTaxNo;

  private String sellerName;

  private String purchaserTaxNo;

  private String purchaserName;

  private String serialNumber;

  private String billCheckStatus;

  private String purchaserCode;

  private LocalDateTime billCheckTime;

  private String remark;

  private String sellerCode;

  private String backOrig;

  private String calculateStatus;

  private String isWarning;

  private String warningInfo;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String currencyType;

  private String contactTel;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  private Long tenantId;

  /**
   * 租户代码
   */
  private String tenantCode;

  /**
   * 创建时间
   */
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  private Long createUserId;

  /**
   * 修改人
   */
  private Long updateUserId;

  /**
   * 创建人名字
   */
  private String createUserName;

  /**
   * 修改人名字
   */
  private String updateUserName;

  /**
   * 删除标记
   */
  private String deleteFlag;




        }

==> image-data-domain-0.0.124-sources.jar: com/xforceplus/elephant/entity/BankBill.java <==
package com.xforceplus.elephant.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-31
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class BankBill implements Serializable {

  private static final long serialVersionUID=1L;

  private Long imageId;

  private String batchNo;

  private String billTypeCode;

  private String billCode;

  private BigDecimal billAmountWithTax;

  private BigDecimal billTaxAmount;

  private BigDecimal billAmountWithoutTax;

  private String billCreateUser;

  private LocalDateTime billCreateTime;

  private Long scanUserId;

  private String scanUserName;

  private LocalDateTime scanCreateTime;

  private String packageCode;

  private String logisticsStatus;

  private LocalDateTime logisticsTime;

  private String signStatus;

  private LocalDateTime signTime;

  private String isPublic;

  private String logisticRemark;

  private String hangType;

  private String hangReason;

  private String backType;

  private String backReason;

  private String billDataStatus;

  private LocalDateTime billDataTime;

  private String verifyStatus;

  private LocalDateTime verifyTime;

  private Long ticketCount;

  private Long imageCount;

  private Long exceptionCount;

  private Long warningCount;

  private String isException;

  private String exceptionInfo;

  private String systemOrig;

  private String isSecret;

  private String backRemark;

  private String unqualityType;

  private String unqualityReason;

  private String verifyHangType;

  private String verifyHangReason;

  private String isPrepayment;

  private String extFields;

  private String extStatus;

  private String prepaymentStatus;

  private LocalDateTime prepaymentTime;

  private String createUserCode;

  private String sellerTaxNo;

  private String sellerName;

  private String purchaserTaxNo;

  private String purchaserName;

  private String serialNumber;

  private String billCheckStatus;

  private String purchaserCode;

  private LocalDateTime billCheckTime;

  private String remark;

  private String sellerCode;

  private String backOrig;

  private String calculateStatus;

  private String isWarning;

  private String warningInfo;

  private String relWarningInfo;

  private String relExceptionInfo;

  private String purchaserNo;

  private String backUser;

  private String testDe;

  private String reserved1;

  private String reserved2;

  private String reserved3;

  private String isCommit;

  private Long commitUserId;

  private String commitUserName;

  private LocalDateTime commitTime;

  private String currencyType;

  private String contactTel;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;




        }
